#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const program = require("commander");
const config_1 = require("./lib/config");
const startup_1 = require("./lib/startup");
(async () => {
    try {
        program
            .version(config_1.meta.version)
            .option('-v, --verbose', 'Verbose output')
            .parse(process.argv);
        await startup_1.checkLoginAndVersion();
        const config = await config_1.read();
        console.log(`Currently logged in to account ${config.acct_id} on world ${config.server}`);
        if (program.verbose) {
            console.log(`Server info: ${JSON.stringify(config.info, null, 2)}`);
        }
        process.exit(0);
    }
    catch (e) {
        if (e === 'Not logged in' || e.toString().match(/^Config file not found/)) {
            console.log('Not logged in');
        }
        else if (program.verbose) {
            console.error(e);
        }
        else {
            console.error('Failed');
        }
        process.exit(1);
    }
})();
//# sourceMappingURL=vvc-info.js.map