#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const program = require("commander");
const config_1 = require("./lib/config");
const startup_1 = require("./lib/startup");
const ws_1 = require("./lib/ws");
(async () => {
    try {
        program
            .version(config_1.meta.version)
            .option('-v, --verbose', 'Verbose output')
            .parse(process.argv);
        await startup_1.checkLoginAndVersion();
        const config = await config_1.read();
        await ws_1.ws(`clients/${config.user_id}`, { method: 'DELETE' });
        await config_1.unlink();
        console.log('Logged out');
        process.exit(0);
    }
    catch (e) {
        if (program.verbose) {
            console.error(e);
        }
        config_1.unlink().then(() => {
            console.log('Logged out');
            process.exit(0);
        }, err => {
            console.error('Logout failed');
            process.exit(1);
        });
    }
})();
//# sourceMappingURL=vvc-logout.js.map